Fuery class

Properties

cache → QueryCache
no setter
defaultOptions QueryOptions
no setter
hashCode int
The hash code for this object.
no setterinherited
mutationCache → MutationCache
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addMutation(MutationKey mutationKey, MutationBase<dynamic, dynamic, dynamic, MutationState> mutation) → void
Add the MutationBase to the MutationCache
addQuery(QueryKey queryKey, QueryBase<dynamic, dynamic, QueryState> query) → void
Add the QueryBase to the QueryCache.
configQueryOptions(QueryOptions? queryOptions) → void
Set QueryOptions globally.
getMutation(MutationKey mutationKey) → MutationBase<dynamic, dynamic, dynamic, MutationState>?
Returns MutationBase if exists.
getMutationData<T>(MutationKey mutationKey) → T?
Returns mutation data if exists.
getQuery(QueryKey queryKey) → QueryBase<dynamic, dynamic, QueryState>?
Return QueryBase if exists.
getQueryData<T>(QueryKey queryKey) → T?
Return query data if exists.
hasMutation(MutationKey mutationKey) bool
Return whether the MutationBase is cached or not.
hasQuery(QueryKey queryKey) bool
Return whether the QueryBase is cached or not.
invalidateQueries({QueryKey? queryKey, bool? exact}) → void
Mark queries as stale.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeMutation(MutationKey mutationKey) → void
Remove MutationBase from the MutationCache.
removeQuery(QueryKey queryKey) → void
Remove QueryBase from the QueryCache.
setQueryData<T>(QueryKey queryKey, T data) → void
Set data If the QueryBase exists based on the queryKey,
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance Fuery
no setter