InfiniteData<Param, Data> class

Constructors

InfiniteData({required Data data, required Param param})
const

Properties

data → Data
final
hashCode int
The hash code for this object.
no setteroverride
param → Param
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override