InfiniteQueryResult<Param, Data, Err> class
Constructors
-
InfiniteQueryResult({required ValueStream<
QueryState< stream, required void refetch(), required void updateOptions(QueryOptions<List< >InfiniteData< , Err>Param, Data> >List< options), required void fetchNextPage(), required void fetchPreviousPage()?, required void reset(), required bool hasNextPage(), required bool hasPreviousPage()})InfiniteData< >Param, Data> >
Properties
-
data
→ Stream<
List< InfiniteData< ?>Param, Data> > -
no setterinherited
-
dataValue
→ List<
InfiniteData< ?Param, Data> > -
no setterinherited
-
error
→ Stream<
Err?> -
no setterinherited
- errorValue → Err?
-
no setterinherited
-
fetchStatus
→ Stream<
FetchStatus> -
no setterinherited
- fetchStatusValue → FetchStatus
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasNextPage → bool
-
no setter
- hasPreviousPage → bool
-
no setter
- isError → bool
-
no setterinherited
- isFetching → bool
-
no setterinherited
- isLoading → bool
-
no setterinherited
- isPending → bool
-
no setterinherited
- isRefetching → bool
-
no setterinherited
- isSuccess → bool
-
no setterinherited
- refetch → void Function()
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
status
→ Stream<
QueryStatus> -
no setterinherited
- statusValue → QueryStatus
-
no setterinherited
-
stream
→ ValueStream<
QueryState< List< >InfiniteData< , Err>Param, Data> > -
no setterinherited
Methods
-
fetchNextPage(
) → void -
fetchPreviousPage(
) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
reset(
) → void -
select<
T> (T selector(List< InfiniteData< pages)) → Stream<Param, Data> >T> -
toString(
) → String -
A string representation of this object.
inherited
-
updateOptions(
{int? gcTime, int? staleTime, int? refetchInterval, List< InfiniteData< ? initialData}) → voidParam, Data> > -
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited