MutationOptions<Params, Data, Err> class

Constructors

MutationOptions({Params? params, int? gcTime, MutationMutateCallback<Params>? onMutate, MutationSuccessCallback<Params, Data>? onSuccess, MutationErrorCallback<Params, Err>? onError})

Properties

gcTime int
no setter
hashCode int
The hash code for this object.
no setteroverride
onError MutationErrorCallback<Params, Err>?
no setter
onMutate MutationMutateCallback<Params>?
no setter
onSuccess MutationSuccessCallback<Params, Data>?
no setter
params → Params?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({ValueGetter<Params>? params, ValueGetter<int>? gcTime, ValueGetter<MutationMutateCallback<Params>>? onMutate, ValueGetter<MutationSuccessCallback<Params, Data>>? onSuccess, ValueGetter<MutationErrorCallback<Params, Err>>? onError}) MutationOptions<Params, Data, Err>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override