MutationResult<Data, Err, MutateType, MutateAsyncType> class

Constructors

MutationResult({required ValueStream<MutationState<Data, Err>> data, required MutateType mutate, required MutateAsyncType mutateAsync})

Properties

data → ValueStream<MutationState<Data, Err>>
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
mutate → MutateType
no setterinherited
mutateAsync → MutateAsyncType
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited