MutationState<Data, Err> class

Constructors

MutationState({Data? data, Err? error, MutationStatus status = MutationStatus.idle})

Properties

data → Data?
finalinherited
error → Err?
finalinherited
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status MutationStatus
finalinherited

Methods

copyWith({ValueGetter<Data>? data, ValueGetter<Err>? error, MutationStatus? status}) MutationState<Data, Err>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override