QueryState<Data, Err> class

Implementers

Constructors

QueryState({Data? data, Err? error, required QueryStatus status, required FetchStatus fetchStatus, required bool invalidated, required Timestamp updatedAt})

Properties

data → Data?
finalinherited
error → Err?
finalinherited
fetchStatus FetchStatus
finalinherited
hashCode int
The hash code for this object.
no setteroverride
invalidated bool
finalinherited
isError bool
no setterinherited
isFetching bool
no setterinherited
isLoading bool
no setterinherited
isPending bool
no setterinherited
isRefetching bool
no setterinherited
isSuccess bool
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status QueryStatus
finalinherited
updatedAt → Timestamp
finalinherited

Methods

copyWith({ValueGetter<Data>? data, ValueGetter<Err>? error, QueryStatus? status, FetchStatus? fetchStatus, bool? invalidated}) QueryState<Data, Err>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override