InfiniteQuery<Param, Data, Err> class
Properties
- encodedKey → String
-
no setterinherited
- hasData → bool
-
Returns true when has data.
no setter
- hasGcTimer → bool
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListener → bool
-
no setterinherited
- hasNextPage → bool
-
Returns true when has next page.
no setter
- hasPreviousPage → bool
-
Return true when has previous page.
no setter
- hasRefetchTimer → bool
-
no setterinherited
- isStale → bool
-
no setterinherited
- key → FueryKey
-
no setterinherited
- options → QueryOptions
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shouldSkipFetch → bool
-
no setterinherited
-
stream
→ ValueStream<
InfiniteQueryState< List< >InfiniteData< , Err>Param, Data> > -
Returns stream of state and Assign
BehaviorSubjectif not exists.no setterinherited
Methods
-
cancelGcTimer(
) → void -
Cancel timer if timer exists.
inherited
-
cancelRefetchTimer(
) → void -
Cancel timer if timer exists.
inherited
-
emit(
InfiniteQueryState< List< state) → voidInfiniteData< , Err>Param, Data> > -
Updates the state to the provided
state.inherited -
fetch(
) → void - Called when an new InfiniteQuery created.
-
fetchNextPage(
) → void - Request next page.
-
fetchPreviousPage(
) → void - Request previous page.
-
invalidate(
) → void - invalidate InfiniteQuery.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
refetch(
) → void - Refresh all pages.
-
reset(
) → void -
Reset all pages and fetch first page based on
initialPageParam. -
setGcTimer(
{required int gcTime, required void callback()}) → void -
Set timer if timer is null.
inherited
-
setRefetchTimer(
{required int interval, required void callback()}) → void -
Set timer if timer is null.
inherited
-
sleep(
) → Future< void> -
Close
BehaviorSubjectand start the garbage collector timer.inherited -
toString(
) → String -
A string representation of this object.
inherited
-
updateOptions(
QueryOptions options) → void -
Updates options to the provided
options.inherited -
wake(
) → void -
Assign a
BehaviorSubject, indicating that listeners can subscribe to it.inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
use<
Param, Data, Err> ({required QueryKey queryKey, required InfiniteQueryFn< Param, Data> queryFn, int? gcTime, int? staleTime, int? refetchInterval, Data? initialData, required Param initialPageParam, required InfiniteQueryNextParamGetter<Param, Data> getNextPageParam, InfiniteQueryPreviousParamGetter<Param, Data> ? getPreviousPageParam, bool? resetOnRefetch}) → InfiniteQueryResult<Param, Data, Err> - Returns InfiniteQueryResult new or existing InfiniteQuery.