QueryResult<Data, Err> class
Constructors
-
QueryResult({required ValueStream<
QueryState< stream, required void refetch(), required void updateOptions(QueryOptions<Data, Err> >Data> options)})
Properties
-
data
→ Stream<
Data?> -
no setterinherited
- dataValue → Data?
-
no setterinherited
-
error
→ Stream<
Err?> -
no setterinherited
- errorValue → Err?
-
no setterinherited
-
fetchStatus
→ Stream<
FetchStatus> -
no setterinherited
- fetchStatusValue → FetchStatus
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- isError → bool
-
no setterinherited
- isFetching → bool
-
no setterinherited
- isLoading → bool
-
no setterinherited
- isPending → bool
-
no setterinherited
- isRefetching → bool
-
no setterinherited
- isSuccess → bool
-
no setterinherited
- refetch → void Function()
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
status
→ Stream<
QueryStatus> -
no setterinherited
- statusValue → QueryStatus
-
no setterinherited
-
stream
→ ValueStream<
QueryState< Data, Err> > -
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
updateOptions(
{int? gcTime, int? staleTime, int? refetchInterval, Data? initialData}) → void -
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited